NormalizerOptions class

Options to be passed into a custom NormalizerFn.

Annotations
  • @JS.new()
  • @anonymous

Constructors

NormalizerOptions()

Properties

collapseWhitespace ↔ bool?
Whether multiple spaces will be collapsed into a single space.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trim ↔ bool?
Whether leading / trailing whitespace will be trimmed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited